@@ -3,7 +3,17 @@
 
 __author__ = "ChenyangGao <https://chenyanggao.github.io>"
 __all__: list[str] = []
-__doc__ = "alist 更新 115 cookie"
+__doc__ = """\
+    alist 更新 115 cookie
+
+你可以先把你的手机抓包得到的 cookie，保存在本地的 ~/115-cookie.txt 中，然后自动进行扫码更新 cookie，自动绑定为微信小程序的 cookie
+
+.. code: console
+
+    /usr/bin/env python3 -m alist 115 --origin 'http://localhost:5244' --user admin --password 123456 --cookie "$(cat ~/115-cookie.txt)" --only-not-work wechatmini
+
+这个命令可以定期运行，比如 1 分钟跑 1 次，在 crontab 里配置
+"""
 
 if __name__ == "__main__":
     from argparse import ArgumentParser, RawTextHelpFormatter
@@ -21,6 +31,7 @@ from urllib.parse import urlencode
 from urllib.request import urlopen, Request
 
 from alist import __version__, AlistClient
+from alist.tool import alist_update_115_cookie
 
 
 AppEnum = Enum("AppEnum", "web, android, ios, linux, mac, windows, tv, alipaymini, wechatmini, qandroid")
@@ -175,7 +186,12 @@ def login_with_qrcode(
     return post_qrcode_result(qrcode_token["uid"], app)
 
 
-def login_with_autoscan(cookie: str, app: str = "web") -> dict:
+def login_with_autoscan(
+    cookie: str, 
+    app: str = "web", 
+) -> dict:
+    """自动扫码登录
+    """
     headers = {"Cookie": cookie}
     token = get_qrcode_token()["data"]
     uid = token["uid"]
@@ -193,24 +209,6 @@ def login_with_autoscan(cookie: str, app: str = "web") -> dict:
     return post_qrcode_result(uid, app)
 
 
-def alist_update_115_cookie(
-    client: AlistClient, 
-    cookie: str, 
-    only_not_work: bool = True, 
-):
-    """更新 alist 中有关 115 的存储的 cookie
-    """
-    storages = client.admin_storage_list()["data"]["content"]
-    for storage in storages:
-        if storage["driver"] in ("115 Cloud", "115 Share"):
-            if only_not_work and storage["status"] == "work":
-                continue
-            addition = loads(storage["addition"])
-            addition["cookie"] = cookie
-            storage["addition"] = dumps(addition)
-            client.admin_storage_update(storage)
-
-
 def main(args):
     if args.version:
         print(".".join(map(str, __version__)))
